@@ -9,5 +9,6 @@ __all__ = [
     "show_or_save", "show_or_return", "Grid", "Saving", "Anneal", "Metrics", "Estimator", "ScalarEMA", "Visualizer",
     "LoggingMixin", "PureLoggingMixin", "SavingMixin", "context_error_handler", "timeit", "lock_manager",
     "batch_manager", "timing_context", "prod", "shallow_copy_dict", "register_core",
-    "data_tuple_saving_controller", "PCManager", "GPUManager", "ResourceManager"
+    "data_tuple_saving_controller", "PCManager", "GPUManager", "ResourceManager",
+    "get_counter_from_arr", "allclose", "Sampler"
 ]
