@@ -282,12 +282,14 @@ def get_unique_indices(arr: np.ndarray) -> UniqueIndices:
     -------
     >>> import numpy as np
     >>> arr = np.array([1, 2, 3, 2, 4, 1, 0, 1], np.int64)
-    >>> print(get_unique_indices(arr, return_raw=True), get_unique_indices(arr)[-1])
-    >>> # [0, 1, 2, 3, 4]
-    >>> # [1, 3, 2, 1, 1]
-    >>> # [6, 0, 5, 7, 1, 3, 2, 4]
-    >>> # [1, 4, 6, 7]
-    >>> # [ [6], [0, 5, 7], [1, 3], [2], [4] ]
+    >>> # UniqueIndices(
+    >>> #   unique          = array([0, 1, 2, 3, 4], dtype=int64),
+    >>> #   unique_cnt      = array([1, 3, 2, 1, 1], dtype=int64),
+    >>> #   sorting_indices = array([6, 0, 5, 7, 1, 3, 2, 4], dtype=int64),
+    >>> #   split_arr       = array([1, 4, 6, 7], dtype=int64))
+    >>> #   split_indices   = [array([6], dtype=int64), array([0, 5, 7], dtype=int64), array([1, 3], dtype=int64),
+    >>> #                      array([2], dtype=int64), array([4], dtype=int64)]
+    >>> print(get_unique_indices(arr))
 
     """
     unique, unique_inv, unique_cnt = np.unique(arr, return_inverse=True, return_counts=True)
@@ -295,12 +297,51 @@ def get_unique_indices(arr: np.ndarray) -> UniqueIndices:
     return UniqueIndices(unique, unique_cnt, sorting_indices, split_arr)
 
 
-def get_counter_from_arr(arr):
+def get_counter_from_arr(arr: np.ndarray) -> Counter:
+    """
+    Get `Counter` of an array
+
+    Parameters
+    ----------
+    arr : np.ndarray, target array which we wish to get `Counter` from
+
+    Returns
+    -------
+    Counter
+
+    Examples
+    -------
+    >>> import numpy as np
+    >>> arr = np.array([1, 2, 3, 2, 4, 1, 0, 1], np.int64)
+    >>> # Counter({1: 3, 2: 2, 0: 1, 3: 1, 4: 1})
+    >>> print(get_counter_from_arr(arr))
+
+    """
     if isinstance(arr, np.ndarray):
         arr = dict(zip(*np.unique(arr, return_counts=True)))
     return Counter(arr)
 
 
+def allclose(*arrays: np.ndarray, **kwargs) -> bool:
+    """
+    Perform `np.allclose` to `arrays` one by one
+
+    Parameters
+    ----------
+    arrays : np.ndarray, target arrays
+    **kwargs : keyword arguments which will be passed into `np.allclose`
+
+    Returns
+    -------
+    allclose : bool
+
+    """
+    for i, arr in enumerate(arrays[:1]):
+        if not np.allclose(arr, arrays[i + 1], **kwargs):
+            return False
+    return True
+
+
 def register_core(name: str,
                   global_dict: Dict[str, type], *,
                   before_register: callable = None,
@@ -742,12 +783,12 @@ class SavingMixin(LoggingMixin):
 
     @property
     @abstractmethod
-    def data_tuple_base(self) -> Type[NamedTuple]:
+    def data_tuple_base(self) -> Union[None, Type[NamedTuple]]:
         pass
 
     @property
     @abstractmethod
-    def data_tuple_attributes(self) -> List[str]:
+    def data_tuple_attributes(self) -> Union[None, List[str]]:
         pass
 
     @property
@@ -1021,6 +1062,61 @@ class Saving(LoggingMixin):
         return _manager()
 
 
+class Sampler:
+    """
+    Util class which can help sampling indices from probabilities
+
+    Parameters
+    ----------
+    method : str, sampling method
+    * currently only 'multinomial' is supported
+    probabilities : np.ndarray, probabilities we'll use
+
+    Examples
+    ----------
+    >>> import numpy as np
+    >>> probabilities = np.array([[0.1, 0.2, 0.3, 0.4], [0.4, 0.3, 0.2, 0.1]], np.float32)
+    >>> sampler = Sampler("multinomial", probabilities)
+    >>> print(sampler.sample(10))
+
+    """
+
+    def __init__(self,
+                 method: str,
+                 probabilities: np.ndarray):
+        self.method = method
+        self.p = probabilities
+        self._p_shape = list(self.p.shape)
+        self._p_block = self.p if self.is_flat else self.p.reshape([-1, self._p_shape[-1]])
+
+    def __str__(self):
+        return f"Sampler({self.method})"
+
+    __repr__ = __str__
+
+    @property
+    def is_flat(self):
+        return len(self._p_shape) == 1
+
+    def _reshape(self, n: int, samples: np.ndarray) -> np.ndarray:
+        return samples.reshape([n] + self._p_shape[:-1]).astype(np.int64)
+
+    def sample(self, n: int) -> np.ndarray:
+        return getattr(self, self.method)(n)
+
+    @staticmethod
+    def _multinomial_flat(n: int, p: np.ndarray) -> np.ndarray:
+        samples = np.random.multinomial(n, p)
+        return np.repeat(np.arange(len(p)), samples)
+
+    def multinomial(self, n: int) -> np.ndarray:
+        if self.is_flat:
+            sampled_indices = self._multinomial_flat(n, self.p)
+        else:
+            sampled_indices = np.vstack([self._multinomial_flat(n, p) for p in self._p_block]).T
+        return self._reshape(n, sampled_indices)
+
+
 # contexts
 
 class context_error_handler:
@@ -1410,7 +1506,7 @@ class data_tuple_saving_controller(context_error_handler):
 __all__ = [
     "get_indices_from_another", "get_unique_indices", "get_one_hot", "hash_code", "prefix_dict",
     "timestamp", "fix_float_to_length", "truncate_string_to_length", "grouped", "is_numeric", "update_dict",
-    "show_or_save", "show_or_return", "Saving", "LoggingMixin", "PureLoggingMixin", "SavingMixin",
+    "show_or_save", "show_or_return", "Saving", "LoggingMixin", "PureLoggingMixin", "SavingMixin", "Sampler",
     "context_error_handler", "timeit", "lock_manager", "batch_manager", "timing_context", "prod",
-    "get_counter_from_arr", "shallow_copy_dict", "register_core", "data_tuple_saving_controller"
+    "get_counter_from_arr", "allclose", "shallow_copy_dict", "register_core", "data_tuple_saving_controller"
 ]
